@@ -1,6 +1,7 @@
+;;; -*- lexical-binding: nil; -*-
 ;;; gfunc.el --- support for generic function
-;;; Copyright (C) 2005-2021
-;;;   HIRAOKA Kazuyuki <khi@users.osdn.me>
+;;; Copyright (C) 2005-2026
+;;;   HIRAOKA Kazuyuki <kakkokakko@gmail.com>
 ;;;
 ;;; This program is free software; you can redistribute it and/or modify
 ;;; it under the terms of the GNU General Public License as published by
@@ -75,7 +76,7 @@ BASE-NAME is name of generic function.
 ARGS-DECLARATION has no effect; it is merely note for programmers.
 DISPATCHERS-VAR is name of variable whose value is list of type-detectors.
 Type-detector receives arguments to the function BASE-NAME, and returns
-its 'type' symbol.
+its \"type\" symbol.
 Then, BASE-NAME + type is the name of real function.
 Type detector must return nil if it cannot determine the type, so that
 the task is chained to next detector."
@@ -83,8 +84,10 @@ the task is chained to next detector."
 
 ARGS = %s
 
-Internally, %s___ is called according to the type of ARGS.
-The type part ___ is determined by functions in the list `%s'.
+Internally, %s___
+is called according to the type of ARGS.
+The type part ___ is determined by functions in the list
+`%s'.
 This function is generated by `gfunc-define-function'."
                           (or description "Generic function.")
                           args-declaration
